@@ -2,7 +2,7 @@ package Test2::Event::Plan;
 use strict;
 use warnings;
 
-our $VERSION = '0.000038';
+our $VERSION = '0.000039';
 
 use base 'Test2::Event';
 use Test2::Util::HashBase qw{max directive reason};
@@ -36,6 +36,15 @@ sub init {
     }
 }
 
+sub sets_plan {
+    my $self = shift;
+    return (
+        $self->{+MAX},
+        $self->{+DIRECTIVE},
+        $self->{+REASON},
+    );
+}
+
 sub callback {
     my $self = shift;
     my ($hub) = @_;
